@@ -45,7 +45,7 @@ mynewt_main(int argc, char **argv)
 
     sysinit();
 
-    g_led_pin = LED_BLINK_PIN;
+    g_led_pin = MYNEWT_VAL(LED_BLINK_PIN);
     hal_gpio_init_out(g_led_pin, 1);
 
     while (1) {
@@ -56,6 +56,10 @@ mynewt_main(int argc, char **argv)
 
         /* Toggle the LED */
         hal_gpio_toggle(g_led_pin);
+
+        if (MYNEWT_VAL(BLINKY_PRINT_LED_STATE)) {
+            printf("LED was toggled %d times.\n", g_task1_loops);
+        }
     }
     assert(0);
 
